@@ -20,9 +20,6 @@ class FiberTissueSimulation(myokit.CModule):
     """
     Runs a simulation of a fiber leading up to a rectangular piece of tissue.
 
-    Note: This simulation class is deprecated as of version 1.33.0, and will be
-    removed in future versions of Myokit.
-
     Takes the following input arguments:
 
     ``fiber_model``
@@ -131,10 +128,11 @@ class FiberTissueSimulation(myokit.CModule):
         super(FiberTissueSimulation, self).__init__()
 
         # Deprecated since 2021-05-28
-        import warnings
-        warnings.warn(
-            'The class `myokit.FiberTissueSimulation` is deprecated, and will'
-            ' be removed in future versions of Myokit.')
+        # Un-deprecated on 2022-04-20, following Adam's request
+        #import warnings
+        #warnings.warn(
+        #    'The class `myokit.FiberTissueSimulation` is deprecated, and will'
+        #    ' be removed in future versions of Myokit.')
 
         # List of globally logged inputs
         self._global = ['time', 'pace']
@@ -145,18 +143,18 @@ class FiberTissueSimulation(myokit.CModule):
 
         # Require independent components
         if fiber_model.has_interdependent_components():
-            cycles = fiber_model.component_cycles()
-            cycles = '\n  '.join([
-                ' > '.join([x.var().qname() for x in c]) for c in cycles])
-            raise Exception(
+            cycles = '\n'.join([
+                '  ' + ' > '.join([x.name() for x in c])
+                for c in fiber_model.component_cycles()])
+            raise ValueError(
                 'This simulation requires models without interdependent'
                 ' components. Please restructure the fiber model and re-run.'
                 ' Cycles:\n' + cycles)
         if tissue_model.has_interdependent_components():
-            cycles = tissue_model.component_cycles()
-            cycles = '\n  '.join([
-                ' > '.join([x.var().qname() for x in c]) for c in cycles])
-            raise Exception(
+            cycles = '\n'.join([
+                '  ' + ' > '.join([x.name() for x in c])
+                for c in tissue_model.component_cycles()])
+            raise ValueError(
                 'This simulation requires models without interdependent'
                 ' components. Please restructure the tissue model and re-run.'
                 ' Cycles:\n' + cycles)
@@ -186,9 +184,9 @@ class FiberTissueSimulation(myokit.CModule):
         self._ncellsf = [int(x) for x in ncells_fiber]
         self._ncellst = [int(x) for x in ncells_tissue]
         if self._ncellsf[0] < 1 or self._ncellsf[1] < 1:
-            raise ValueError('The fiber must be at least (1,1).')
+            raise ValueError('The fiber size must be at least (1, 1).')
         if self._ncellst[0] < 1 or self._ncellst[1] < 1:
-            raise ValueError('The tissue size must be at least (1,1).')
+            raise ValueError('The tissue size must be at least (1, 1).')
         if self._ncellsf[1] > self._ncellst[1]:
             raise ValueError(
                 'The fiber y-dimension cannot exceed that of the tissue.')
@@ -205,12 +203,18 @@ class FiberTissueSimulation(myokit.CModule):
                 self._paced_cells.append(x + y * self._ncellsf[0])
 
         # Check conductivities
-        if len(g_fiber) != 2:
-            raise ValueError(
-                'The fiber conductivity must be a tuple (gx,gy).')
-        if len(g_tissue) != 2:
-            raise ValueError(
-                'The tissue conductivity must be a tuple (gx,gy).')
+        msg = 'The fiber conductivity must be a tuple (gx, gy).'
+        try:
+            if len(g_fiber) != 2:
+                raise ValueError(msg)
+        except TypeError:
+            raise ValueError(msg)
+        msg = 'The tissue conductivity must be a tuple (gx, gy).'
+        try:
+            if len(g_tissue) != 2:
+                raise ValueError(msg)
+        except TypeError:
+            raise ValueError(msg)
         self._gf = [float(x) for x in g_fiber]
         self._gt = [float(x) for x in g_tissue]
         self._gft = float(g_fiber_tissue)
@@ -244,31 +248,31 @@ class FiberTissueSimulation(myokit.CModule):
         # Get membrane potential variables
         self._vmf = self._modelf.label('membrane_potential')
         if self._vmf is None:
-            raise Exception(
+            raise ValueError(
                 'This simulation requires the membrane potential variable to'
                 ' be labelled as "membrane_potential" in the fiber model.')
         if not self._vmf.is_state():
-            raise Exception(
+            raise ValueError(
                 'The variable labelled as membrane potential in the fiber'
-                ' model must be a state variale.')
+                ' model must be a state variable.')
         self._vmt = self._modelt.label('membrane_potential')
         if self._vmt is None:
-            raise Exception(
+            raise ValueError(
                 'This simulation requires the membrane potential variable to'
                 ' be labelled as "membrane_potential" in the tissue model.')
         if not self._vmt.is_state():
-            raise Exception(
+            raise ValueError(
                 'The variable labelled as membrane potential in the tissue'
-                ' model must be a state variale.')
+                ' model must be a state variable.')
 
         # Check for binding to diffusion_current
         if self._modelf.binding('diffusion_current') is None:
-            raise Exception(
+            raise ValueError(
                 'This simulation requires a variable in the fiber model to be'
                 ' bound to "diffusion_current" to pass current from one cell'
                 ' to the next.')
         if self._modelt.binding('diffusion_current') is None:
-            raise Exception(
+            raise ValueError(
                 'This simulation requires a variable in the tissue model to be'
                 ' bound to "diffusion_current" to pass current from one cell'
                 ' to the next.')
@@ -276,16 +280,14 @@ class FiberTissueSimulation(myokit.CModule):
         # Check if membrane potentials have same unit
         uvf = self._vmf.unit()
         if uvf is None:
-            raise Exception(
-                'The fiber model must specify a unit for the membrane'
-                ' potential.')
+            raise ValueError('The fiber model must specify a unit for the'
+                             ' membrane potential.')
         uvt = self._vmt.unit()
         if uvt is None:
-            raise Exception(
-                'The tissue model must specify a unit for the membrane'
-                ' potential.')
+            raise ValueError('The tissue model must specify a unit for the'
+                             ' membrane potential.')
         if uvf != uvt:
-            raise Exception(
+            raise ValueError(
                 'The membrane potential must have the same unit in the fiber'
                 ' and the tissue model: ' + str(uvf) + ' vs ' + str(uvt) + '.')
 
@@ -293,15 +295,13 @@ class FiberTissueSimulation(myokit.CModule):
         ucf = self._modelf.binding('diffusion_current').unit()
         uct = self._modelt.binding('diffusion_current').unit()
         if ucf is None:
-            raise Exception(
-                'The fiber model must specify a unit for the diffusion'
-                ' current.')
+            raise ValueError('The fiber model must specify a unit for the'
+                             ' diffusion current.')
         if uct is None:
-            raise Exception(
-                'The tissue model must specify a unit for the diffusion'
-                ' current.')
+            raise ValueError('The tissue model must specify a unit for the'
+                             ' diffusion current.')
         if ucf != uct:
-            raise Exception(
+            raise ValueError(
                 'The diffusion current must have the same unit in the fiber'
                 ' and the tissue model: ' + str(ucf) + ' vs ' + str(uct) + '.')
 
@@ -374,23 +374,94 @@ class FiberTissueSimulation(myokit.CModule):
             mname, fname, args, libs, libd, incd, larg=flags,
             continue_in_debug_mode=True)
 
-    def fiber_state(self, x=None):
+    def default_fiber_state(self, x=None, y=None):
+        """
+        Returns the current default simulation state for the fiber model as a
+        list of ``len(state) * n_total_cells`` floating point values, where
+        ``n_total_cells`` is the total number of fiber cells.
+
+        If the optional arguments ``x`` and ``y`` specify a valid cell index, a
+        single cell's state is returned.
+
+        The returned list is indexed so that x changes first (the first ``nx``
+        entries have ``y = 0``, the second ``nx`` entries have ``y = 1`` and so
+        on).
+        """
+        if x is None:
+            return list(self._default_statef)
+        elif y is None:
+            raise ValueError('default_fiber_state() must be called with no'
+                             ' arguments or with both an x and y argument.')
+        else:
+            nx, ny = self._ncellsf
+            x = int(x or 0)
+            if x < 0 or x >= nx:
+                raise IndexError('Given x-index out of range.')
+            y = int(y or 0)
+            if y < 0 or y >= ny:
+                raise IndexError('Given y-index out of range.')
+            x += y * nx
+            return self._default_statef[
+                x * self._nstatef:(x + 1) * self._nstatef]
+
+    def default_tissue_state(self, x=None, y=None):
+        """
+        Returns the current default simulation state for the tissue model as a
+        list of ``len(state) * n_total_cells`` floating point values, where
+        ``n_total_cells`` is the total number of tissue cells.
+
+        If the optional arguments ``x`` and ``y`` specify a valid cell index, a
+        single cell's state is returned.
+
+        The returned list is indexed so that x changes first (the first ``nx``
+        entries have ``y = 0``, the second ``nx`` entries have ``y = 1`` and so
+        on).
+        """
+        if x is None:
+            return list(self._default_statet)
+        elif y is None:
+            raise ValueError('default_tissue_state() must be called with no'
+                             ' arguments or with both an x and y argument.')
+        else:
+            nx, ny = self._ncellst
+            x = int(x or 0)
+            if x < 0 or x >= nx:
+                raise IndexError('Given x-index out of range.')
+            y = int(y or 0)
+            if y < 0 or y >= ny:
+                raise IndexError('Given y-index out of range.')
+            x += y * nx
+            return self._default_statet[
+                x * self._nstatet:(x + 1) * self._nstatet]
+
+    def fiber_shape(self):
+        """
+        Returns the shape of this simulation's grid of fiber cells as a tuple
+        ``(ny, nx)``.
+        """
+        # TODO: See https://github.com/MichaelClerx/myokit/issues/764
+        return (self._ncellsf[1], self._ncellsf[0])
+
+    def fiber_state(self, x=None, y=None):
         """
         Returns the current simulation state in the fiber as a list of
         ``len(state_fiber) * ncells_fiber`` floating point values.
 
         If the optional arguments ``x`` and ``y`` specify a valid cell index a
-        single cell's state is returned.
+        single fiber cell's state is returned.
         """
         if x is None:
             return list(self._statef)
+        elif y is None:
+            raise ValueError('fiber_state() must be called with no arguments'
+                             ' or with both an x and y argument.')
         else:
             x = int(x)
-            if x < 0 or x > self._ncellsf[0]:
-                raise KeyError('Given x-index out of range.')
+            if x < 0 or x >= self._ncellsf[0]:
+                raise IndexError('Given x-index out of range.')
             y = int(y)
-            if y < 0 or y > self._ncellsf[1]:
-                raise KeyError('Given y-index out of range.')
+            if y < 0 or y >= self._ncellsf[1]:
+                raise IndexError('Given y-index out of range.')
             x += y * self._ncellsf[0]
             return self._statef[x * self._nstatef:(x + 1) * self._nstatef]
 
@@ -478,7 +549,7 @@ class FiberTissueSimulation(myokit.CModule):
                     # Earlier NaN found
                     kfirst = key
                     ifirst = bisect(ar, 0, ifirst)
-                    if ifirst == 0:
+                    if ifirst == 0:  # pragma: no cover
                         break
             return ifirst, kfirst
 
@@ -492,9 +563,9 @@ class FiberTissueSimulation(myokit.CModule):
             ifirstt, kfirstt = find_error_position(_logt)
             if kfirstf is None and kfirstt is None:
                 raise myokit.FindNanError('Error condition not found in logs.')
-            elif kfirstf is None:
+            elif kfirstf is None:  # pragma: no cover
                 ifirst = ifirstt
-            elif kfirstt is None:
+            elif kfirstt is None:  # pragma: no cover
                 ifirst = ifirstf
             elif ifirstf == 0 or ifirstt == 0:
                 raise myokit.FindNanError(
@@ -584,7 +655,7 @@ class FiberTissueSimulation(myokit.CModule):
         bound = []
         max_states = 3
         for k in range(ifirst, ifirst - max_states - 1, -1):
-            if k < 0:
+            if k < 0:  # pragma: no cover
                 break
             s, b = state(k, icell)
             states.append(s)
@@ -603,8 +674,7 @@ class FiberTissueSimulation(myokit.CModule):
         # Return part, time, icell, variable, value, states, bound
         return part, time, icell, var, value, states, bound
 
-    def pre(
-            self, duration, report_nan=True, progress=None,
+    def pre(self, duration, report_nan=True, progress=None,
             msg='Pre-pacing FiberTissueSimulation'):
         """
         This method can be used to perform an unlogged simulation, typically to
@@ -624,9 +694,8 @@ class FiberTissueSimulation(myokit.CModule):
         passed in as ``progress``. An optional description of the current
         simulation to use in the ProgressReporter can be passed in as `msg`.
         """
-        self._run(
-            duration, myokit.LOG_NONE, myokit.LOG_NONE, 1, report_nan,
-            progress, msg)
+        self._run(duration, myokit.LOG_NONE, myokit.LOG_NONE, 1, report_nan,
+                  progress, msg)
         self._default_statef = list(self._statef)
         self._default_statet = list(self._statet)
 
@@ -702,12 +771,11 @@ class FiberTissueSimulation(myokit.CModule):
         self._time += duration
         return r
 
-    def _run(
-            self, duration, logf, logt, log_interval, report_nan, progress,
-            msg):
+    def _run(self, duration, logf, logt, log_interval, report_nan, progress,
+             msg):
         # Simulation times
         if duration < 0:
-            raise Exception('Simulation duration can\'t be negative.')
+            raise ValueError('Simulation duration can\'t be negative.')
         tmin = self._time
         tmax = tmin + duration
 
@@ -860,7 +928,7 @@ class FiberTissueSimulation(myokit.CModule):
                         r = 1.0 / duration if duration != 0 else 1
                         while t < tmax:
                             t = self._sim.sim_step()
-                            if t < tmin:
+                            if t < tmin:    # pragma: no cover
                                 # A numerical error has occurred.
                                 break
                             if not progress.update(min((t - tmin) * r, 1)):
@@ -880,7 +948,7 @@ class FiberTissueSimulation(myokit.CModule):
             self._statet = state_outt
 
         # Check for NaN's, print error output
-        if report_nan and (logf.has_nan() or logt.has_nan()):
+        if (report_nan and (logf.has_nan() or logt.has_nan())):
             txt = ['Numerical error found in simulation logs.']
             try:
                 # NaN encountered, show how it happened
@@ -906,7 +974,7 @@ class FiberTissueSimulation(myokit.CModule):
                             states[1], precision=self._precision)
                         txt.append(model.format_state_derivatives(
                             states[1], derivs))
-                    except myokit.NumericalError as ee:
+                    except myokit.NumericalError as ee:  # pragma: no cover
                         txt.append(str(ee))
             except myokit.FindNanError as e:
                 txt.append(
@@ -926,18 +994,21 @@ class FiberTissueSimulation(myokit.CModule):
         if n == self._nstatef * ntotalf:
             return list(state)
         elif n != self._nstatef:
-            raise ValueError(
-                'Given state must have the same size as a'
-                ' single cell state or a full simulation state')
+            raise ValueError('Given state must have the same size as a single'
+                             ' fiber cell state or a full simulation state')
         if x is None:
             return list(state) * ntotalf
+        elif y is None:
+            raise ValueError(
+                'Must provide no coordinates, or both x and y coordinates.')
+
         # Set specific cell state
         x = int(x)
-        if x < 0 or x > self._ncellsf[0]:
-            raise KeyError('Given x-index out of range.')
+        if x < 0 or x >= self._ncellsf[0]:
+            raise IndexError('Given x-index out of range.')
         y = int(y)
-        if y < 0 or y > self._ncellsf[1]:
-            raise KeyError('Given y-index out of range.')
+        if y < 0 or y >= self._ncellsf[1]:
+            raise IndexError('Given y-index out of range.')
         offset = (x + y * self._ncellsf[0]) * self._nstatef
         update[offset:offset + self._nstatef] = state
         return update
@@ -951,18 +1022,21 @@ class FiberTissueSimulation(myokit.CModule):
         if n == self._nstatet * ntotalt:
             return list(state)
         elif n != self._nstatet:
-            raise ValueError(
-                'Given state must have the same size as a single'
-                ' cell state or a full simulation state')
+            raise ValueError('Given state must have the same size as a single'
+                             ' tissue cell state or a full simulation state')
         if x is None:
             return list(state) * ntotalt
+        elif y is None:
+            raise ValueError(
+                'Must provide no coordinates, or both x and y coordinates.')
+
         # Set specific cell state
         x = int(x)
-        if x < 0 or x > self._ncellst[0]:
-            raise KeyError('Given x-index out of range.')
+        if x < 0 or x >= self._ncellst[0]:
+            raise IndexError('Given x-index out of range.')
         y = int(y)
-        if y < 0 or y > self._ncellst[1]:
-            raise KeyError('Given y-index out of range.')
+        if y < 0 or y >= self._ncellst[1]:
+            raise IndexError('Given y-index out of range.')
         offset = (x + y * self._ncellst[0]) * self._nstatet
         update[offset: offset + self._nstatet] = state
         return update
@@ -974,14 +1048,17 @@ class FiberTissueSimulation(myokit.CModule):
         This can be used in three different ways:
 
         1. When called with an argument ``state`` of size ``n_states`` and
-           ``x=y=None`` the given state will be set as the new default state of
+           ``x=None`` the given state will be set as the new default state of
            all fiber cells in the simulation.
-        2. Called with an argument ``state`` of size n_states and
+        2. Called with an argument ``state`` of size ``n_states`` and
            ``x, y`` equal to a valid cell index, this method will update only
            the selected fiber cell's default state.
-        3. Finally, when called with a ``state`` of size ``n_states * n_cells``
-           the method will treat ``state`` as a concatenation of state vectors
-           for each fiber cell.
+        3. Finally, when called with a ``state`` of size
+           ``n_states * n_total_cells``, the method will treat ``state`` as a
+           concatenation of default state vectors for each fiber cell. For 2d
+           simulations, the list should be indexed so that x changes first (the
+           first ``nx`` entries have ``y = 0``, the second ``nx`` entries have
+           ``y = 1`` and so on).
 
         """
         self._default_statef = self._set_statef(
@@ -995,13 +1072,16 @@ class FiberTissueSimulation(myokit.CModule):
 
         1. When called with an argument ``state`` of size ``n_states`` and
            ``x=None`` the given state will be set as the new default state of
-           tissue cells in the simulation.
-        2. Called with an argument ``state`` of size n_states and
+           all tissue cells in the simulation.
+        2. Called with an argument ``state`` of size ``n_states`` and
            ``x, y`` equal to a valid cell index, this method will update only
            the selected tissue cell's default state.
-        3. Finally, when called with a ``state`` of size ``n_states * n_cells``
-           the method will treat ``state`` as a concatenation of state vectors
-           for each tissue cell.
+        3. Finally, when called with a ``state`` of size
+           ``n_states * n_total_cells``, the method will treat ``state`` as a
+           concatenation of default state vectors for each tissue cell. For 2d
+           simulations, the list should be indexed so that x changes first (the
+           first ``nx`` entries have ``y = 0``, the second ``nx`` entries have
+           ``y = 1`` and so on).
 
         """
         self._default_statet = self._set_statet(
@@ -1014,14 +1094,17 @@ class FiberTissueSimulation(myokit.CModule):
         This can be used in three different ways:
 
         1. When called with an argument ``state`` of size ``n_states`` and
-           ``x=y=None`` the given state will be set as the new state of all
+           ``x=None`` the given state will be set as the new state of all
            fiber cells in the simulation.
-        2. Called with an argument ``state`` of size n_states and
+        2. Called with an argument ``state`` of size ``n_states`` and
            ``x, y`` equal to a valid cell index, this method will update only
            the selected fiber cell's state.
-        3. Finally, when called with a ``state`` of size ``n_states * n_cells``
-           the method will treat ``state`` as a concatenation of state vectors
-           for each fiber cell.
+        3. Finally, when called with a ``state`` of size
+           ``n_states * n_total_cells``, the method will treat ``state`` as a
+           concatenation of state vectors for each fiber cell. For 2d
+           simulations, the list should be indexed so that x changes first (the
+           first ``nx`` entries have ``y = 0``, the second ``nx`` entries have
+           ``y = 1`` and so on).
 
         """
         self._statef = self._set_statef(state, x, y, self._statef)
@@ -1033,43 +1116,56 @@ class FiberTissueSimulation(myokit.CModule):
         This can be used in three different ways:
 
         1. When called with an argument ``state`` of size ``n_states`` and
-           ``x=y=None`` the given state will be set as the new state of all
+           ``x=None`` the given state will be set as the new state of all
            tissue cells in the simulation.
-        2. Called with an argument ``state`` of size n_states and
+        2. Called with an argument ``state`` of size ``n_states`` and
            ``x, y`` equal to a valid cell index, this method will update only
            the selected tissue cell's state.
-        3. Finally, when called with a ``state`` of size ``n_states * n_cells``
-           the method will treat ``state`` as a concatenation of state vectors
-           for each tissue cell.
+        3. Finally, when called with a ``state`` of size
+           ``n_states * n_total_cells``, the method will treat ``state`` as a
+           concatenation of state vectors for each tissue cell. For 2d
+           simulations, the list should be indexed so that x changes first (the
+           first ``nx`` entries have ``y = 0``, the second ``nx`` entries have
+           ``y = 1`` and so on).
 
         """
         self._statet = self._set_statet(state, x, y, self._statet)
 
     def set_step_size(self, step_size=0.005):
-        """
-        Sets the solver step size.
-        """
+        """ Sets the solver step size. """
         step_size = float(step_size)
         if step_size <= 0:
             raise ValueError('Step size must be greater than zero.')
         self._step_size = step_size
 
     def set_protocol(self, protocol=None):
-        """
-        Changes the pacing protocol used by this simulation.
-        """
+        """ Changes the pacing protocol used by this simulation. """
         if protocol is None:
             self._protocol = None
         else:
             self._protocol = protocol.clone()
 
     def set_time(self, time=0):
-        """
-        Sets the current simulation time.
-        """
+        """ Sets the current simulation time. """
         self._time = float(time)
 
-    def tissue_state(self, x=None):
+    def step_size(self, step_size=0.005):
+        """ Returns the solver step size. """
+        return self._step_size
+
+    def time(self):
+        """ Returns the current simulation time """
+        return self._time
+
+    def tissue_shape(self):
+        """
+        Returns the shape of this simulation's grid of tissue cells as a tuple
+        ``(ny, nx)``.
+        """
+        # TODO: See https://github.com/MichaelClerx/myokit/issues/764
+        return (self._ncellst[1], self._ncellst[0])
+
+    def tissue_state(self, x=None, y=None):
         """
         Returns the current simulation state in the tissue as a list of
         ``len(state_tissue) * ncells_tissue`` floating point values.
@@ -1079,18 +1175,16 @@ class FiberTissueSimulation(myokit.CModule):
         """
         if x is None:
             return list(self._statet)
+        elif y is None:
+            raise ValueError('tissue_state() must be called with no arguments'
+                             ' or with both an x and y argument.')
         else:
             x = int(x)
-            if x < 0 or x > self._ncellst[0]:
-                raise KeyError('Given x-index out of range.')
+            if x < 0 or x >= self._ncellst[0]:
+                raise IndexError('Given x-index out of range.')
             y = int(y)
-            if y < 0 or y > self._ncellst[1]:
-                raise KeyError('Given y-index out of range.')
+            if y < 0 or y >= self._ncellst[1]:
+                raise IndexError('Given y-index out of range.')
             x += y * self._ncellst[0]
             return self._statet[x * self._nstatet:(x + 1) * self._nstatet]
 
-    def time(self):
-        """
-        Returns the current simulation time.
-        """
-        return self._time
