@@ -16,7 +16,7 @@ import numpy as np
 
 import myokit
 
-from shared import DIR_DATA, WarningCollector
+from myokit.tests import DIR_DATA, WarningCollector
 
 # Unit testing in Python 2 and 3
 try:
